==> ksr-3.8.2.tgz: package/configuration/webpack/webpackConfig.js <==
const path = require("path");
const merge = require("webpack-merge");
const base = require("./baseConf");
const intact = require("./intactConf");
const component = require("./componentConf");
const vue = require("./vueConf");
const ts = require("./tsConf");
const getExternalsConf = require("./getExternalsConf");
const _ = require("lodash");

function defaultKsrConfig(min, isDev, program) {
  let assetsPublicPath = program.cdn ? program.cdn : "/";
  assetsPublicPath = /\/$/.test(assetsPublicPath)
    ? assetsPublicPath
    : `${assetsPublicPath}/`;
  let enableHash = program.hash !== 'false' ? program.hash : false
  const filename = !enableHash ? "[name]" : "[name].[chunkhash:6].min";
  const assetsName =  !enableHash ? `[name].[ext]` : `[name].[hash].[ext]`;
  return {
    root: ".",
    src: "src",
    dist: program.output || 'dist',
    library: program.library || undefined,
    libraryTarget: program.target || undefined,
    filename: filename,
    chunkFilename: `chunks/${filename}`,
    assetsName: assetsName,
    assetsPublicPath: assetsPublicPath,
    assetsOutPath: "assets/",
    stylTheme: "~kpc/styles/themes/ksyun/index.styl",
    hot: {},
    dev: {},
    pathConvert: file => {
      return !path.isAbsolute(file) ? path.resolve(process.cwd(), file) : file;
    },
    transform: webpack => {
      return webpack;
    }
  };
}

module.exports = function(program, type) {
  let { webpack, ksr, ksrServe } = getExternalsConf(program.config);
  const isDev = type === "dev";
  program.min = program.min === "true"
  ksr = _.defaultsDeep({}, program, ksr, defaultKsrConfig(program.min, isDev, program));
  // 可用的参数列表
  webpack = merge.smart(
    ts(program, ksr, isDev),
    vue(program, ksr, isDev),
    base(program, ksr, isDev, webpack),
    intact(program, ksr, isDev),
    component(program, ksr, isDev),
    webpack
  );
  const trans = ksr.transform(webpack);
  webpack = !_.isEmpty(trans) && trans ? trans : webpack;
  return {
    webpack,
    ksr,
    ksrServe
  };
};

==> ksr-4.0.3.tgz: package/configuration/webpack/webpackConfig.js <==
const path = require("path");
const merge = require("webpack-merge");
const base = require("./baseConf");
const intact = require("./intactConf");
const component = require("./componentConf");
const vue = require("./vueConf");
const ts = require("./tsConf");
const getExternalsConf = require("./getExternalsConf");
const _ = require("lodash");

function defaultKsrConfig(min, isDev, program) {
  let assetsPublicPath = program.cdn ? program.cdn : "/";
  assetsPublicPath = /\/$/.test(assetsPublicPath)
    ? assetsPublicPath
    : `${assetsPublicPath}/`;
  let enableHash = program.hash !== 'false' ? program.hash : false
  const filename = !enableHash ? "[name]" : "[name].[chunkhash].min";
  const assetsName =  !enableHash ? `[name].[ext]` : `[name].[contenthash].[ext]`;
  return {
    root: ".",
    src: "src",
    dist: program.output || 'dist',
    library: program.library || undefined,
    libraryTarget: program.target || undefined,
    filename: filename,
    chunkFilename: `chunks/${filename}`,
    assetsName: assetsName,
    assetsPublicPath: assetsPublicPath,
    assetsOutPath: "assets/",
    stylTheme: "~kpc/styles/themes/ksyun/index.styl",
    hot: {},
    dev: {},
    pathConvert: file => {
      return !path.isAbsolute(file) ? path.resolve(process.cwd(), file) : file;
    },
    transform: webpack => {
      return webpack;
    }
  };
}

module.exports = function(program, type) {
  let { webpack, ksr, ksrServe } = getExternalsConf(program.config);
  const isDev = type === "dev";
  program.min = program.min === "true"
  program.polyfill = program.polyfill === "true"
  ksr = _.defaultsDeep({}, program, ksr, defaultKsrConfig(program.min, isDev, program));
  // 可用的参数列表
  webpack = merge.smart(
    ts(program, ksr, isDev),
    vue(program, ksr, isDev),
    base(program, ksr, isDev, webpack),
    intact(program, ksr, isDev),
    component(program, ksr, isDev),
    webpack
  );
  const trans = ksr.transform(webpack);
  webpack = !_.isEmpty(trans) && trans ? trans : webpack;
  return {
    webpack,
    ksr,
    ksrServe
  };
};
